@@ -8,7 +8,7 @@ mk_accessors(
         select distinct select_map select_map_reverse
         from joins where bind bind_col limit offset group order
         having where_values column_mutator index_hint
-        comment
+        comment for_update
         skinny
     /
 );
@@ -104,6 +104,9 @@ sub as_sql {
     if ($comment && $comment =~ /([ 0-9a-zA-Z.:;()_#&,]+)/) {
         $sql .= "-- $1" if $1;
     }
+
+    $sql .= $self->as_for_update;
+
     return $sql;
 }
 
@@ -227,6 +230,11 @@ sub add_having {
     push @{ $self->{bind} }, @$bind;
 }
 
+sub as_for_update {
+    my $self = shift;
+    $self->for_update ? ' FOR UPDATE' : '';
+}
+
 sub _mk_term {
     my $self = shift;
     my($col, $val) = @_;
